@@ -312,9 +312,9 @@ def create_path(data_path, certbase, rights, group_rights, local_data_path):
     if not os.path.isfile(group_rights):
         group_rights_text = ('# example of content:\n'
                              '#manager pid_info,list_pid,cl_template,install\n' 
-                             'update_system update,setupsystem,configure')
+                             'system_update update,setupsystem,configure')
         fgr = open(group_rights, 'w')
-        fgr.write(group_rights_text)
+        fgr.write("%s\n"%group_rights_text)
         fgr.close()
         # if not os.path.exists(data_path+'/server_certs/CRL'):
         # open(data_path+'/server_certs/CRL', 'w')
